/***************************************************************************
 *   Copyright (C) 2004 by Patrick Steiner                                 *
 *   patrick.steiner@a1.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#include "militaryalphabet.h"
#include <qapplication.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qmultilineedit.h>

// sound
#include <qpe/sound.h>

// timer
#include <qtimer.h>

static const QString programVersion = "0.2.1";
static const QString programName = "Military Alphabet";

static const QString StartMSG = programName + 
				" Ver. " + 
				programVersion + 
                                "\nby Patrick Steiner <patrick.steiner@a1.net>";

// sound counter
unsigned int soundCounter = 0;

// morse counter
unsigned int morseCounter = 0;

MilAlp::MilAlp( QWidget* parent,  const char* name, WFlags fl )
    : MilAlpBase( parent, name, fl )
{
	setCaption(programName + " " + programVersion);
    
	MultiLineEdit1->setText(StartMSG);
	connect(quit, SIGNAL(clicked()), this, SLOT(goodBye()));
	connect(btnAudioOutput, SIGNAL(clicked()), this, SLOT(startSoundTimer()));
	connect(btnMorseOutput, SIGNAL(clicked()), this, SLOT(startMorseTimer()));
	connect(LineEdit2, SIGNAL(textChanged(const QString&)), this, SLOT(convertKeys(const QString&)) );
}

/*  
 *  Destroys the object and frees any allocated resources
 */
MilAlp::~MilAlp()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  end programm
 */
void MilAlp::goodBye()
{
    close();
}

/*
 *  start sound timer
 */
void MilAlp::startSoundTimer()
{
	MultiLineEdit1->setText("");
	
	unsigned int j = 0;
	unsigned int i;
	soundCounter = 0;
	const QString inputMSG = LineEdit2->text();
	
	for(i=0; i<inputMSG.length(); i++)
	{
		QTimer *timer = new QTimer( this, "MilAlpSound" );
		connect( timer, SIGNAL(timeout() ), this, SLOT( playSoundString()) );
		timer->start( j*1000, TRUE );           
		
		j = j + 1;
	}

}

/*
 *  start morse code timer
 */
void MilAlp::startMorseTimer()
{
	MultiLineEdit1->setText("");
	
	unsigned int j = 0;
	unsigned int i;
	morseCounter = 0;
	const QString inputMSG = LineEdit2->text();
	
	for(i=0; i<inputMSG.length(); i++)
	{
		QTimer *timer = new QTimer( this, "MilAlpMorse" );
		connect( timer, SIGNAL(timeout() ), this, SLOT( playMorseString()) );
		timer->start( j*1000, TRUE );           
		
		j = j + 1;
	}

}

/*
 *  convert string an play wav
 */
void MilAlp::playSoundString()
{	
	const QString cutsoundMSG = LineEdit2->text();

	if( cutsoundMSG[soundCounter] == "a" || cutsoundMSG[soundCounter] == "A" )
	{
		MultiLineEdit1->insert( "Alpha\n" );
		Sound mySound("militaryalphabet/alpha");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "b" || cutsoundMSG[soundCounter] == "B" )
	{
		MultiLineEdit1->insert( "Bravo\n" );
		Sound mySound("militaryalphabet/bravo");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "c" || cutsoundMSG[soundCounter] == "C" )
	{
		MultiLineEdit1->insert( "Charlie\n" );
		Sound mySound("militaryalphabet/charlie");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "d" || cutsoundMSG[soundCounter] == "D" )
	{
		MultiLineEdit1->insert( "Delta\n" );
		Sound mySound("militaryalphabet/delta");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "e" || cutsoundMSG[soundCounter] == "E" )
	{
		MultiLineEdit1->insert( "Echo\n" );
		Sound mySound("militaryalphabet/echo");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "f" || cutsoundMSG[soundCounter] == "F" )
	{
		MultiLineEdit1->insert( "Foxtrot\n" );
		Sound mySound("militaryalphabet/foxtrot");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "g" || cutsoundMSG[soundCounter] == "G" )
	{
		MultiLineEdit1->insert( "Golf\n" );
		Sound mySound("militaryalphabet/golf");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "h" || cutsoundMSG[soundCounter] == "H" )
	{
		MultiLineEdit1->insert( "Hotel\n" );
		Sound mySound("militaryalphabet/hotel");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "i" || cutsoundMSG[soundCounter] == "I" )
	{
		MultiLineEdit1->insert( "India\n" );
		Sound mySound("militaryalphabet/india");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "j" || cutsoundMSG[soundCounter] == "J" )
	{
		MultiLineEdit1->insert( "Juliet\n" );
		Sound mySound("militaryalphabet/juliet");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "k" || cutsoundMSG[soundCounter] == "K" )
	{
		MultiLineEdit1->insert( "Kilo\n" );
		Sound mySound("militaryalphabet/kilo");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "l" || cutsoundMSG[soundCounter] == "L" )
	{
		MultiLineEdit1->insert( "Lima\n" );
		Sound mySound("militaryalphabet/lima");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "m" || cutsoundMSG[soundCounter] == "M" )
	{
		MultiLineEdit1->insert( "Mike\n" );
		Sound mySound("militaryalphabet/mike");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "n" || cutsoundMSG[soundCounter] == "N" )
	{
		MultiLineEdit1->insert( "November\n" );
		Sound mySound("militaryalphabet/november");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "o" || cutsoundMSG[soundCounter] == "O" )
	{
		MultiLineEdit1->insert( "Oscar\n" );
		Sound mySound("militaryalphabet/oscar");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "p" || cutsoundMSG[soundCounter] == "P" )
	{
		MultiLineEdit1->insert( "Papa\n" );
		Sound mySound("militaryalphabet/papa");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "q" || cutsoundMSG[soundCounter] == "Q" )
	{
		MultiLineEdit1->insert( "Quebec\n" );
		Sound mySound("militaryalphabet/quebec");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "r" || cutsoundMSG[soundCounter] == "R" )
	{
		MultiLineEdit1->insert( "Romeo\n" );
		Sound mySound("militaryalphabet/romeo");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "s" || cutsoundMSG[soundCounter] == "S" )
	{
		MultiLineEdit1->insert( "Sierra\n" );
		Sound mySound("militaryalphabet/sierra");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "t" || cutsoundMSG[soundCounter] == "T" )
	{
		MultiLineEdit1->insert( "Tango\n" );
		Sound mySound("militaryalphabet/tango");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "u" || cutsoundMSG[soundCounter] == "U" )
	{
		MultiLineEdit1->insert( "Uniform\n" );
		Sound mySound("militaryalphabet/uniform");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "v" || cutsoundMSG[soundCounter] == "V" )
	{
		MultiLineEdit1->insert( "Victor\n" );
		Sound mySound("militaryalphabet/victor");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "w" || cutsoundMSG[soundCounter] == "W" )
	{
		MultiLineEdit1->insert( "Whiskey\n" );
		Sound mySound("militaryalphabet/whiskey");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "x" || cutsoundMSG[soundCounter] == "X" )
	{
		MultiLineEdit1->insert( "X-Ray\n" );
		Sound mySound("militaryalphabet/xray");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "y" || cutsoundMSG[soundCounter] == "Y" )
	{
		MultiLineEdit1->insert( "Yankee\n" );
		Sound mySound("militaryalphabet/yankee");
		mySound.play();
	}
	else if( cutsoundMSG[soundCounter] == "z" || cutsoundMSG[soundCounter] == "Z" )
	{
		MultiLineEdit1->insert( "Zulu\n" );
		Sound mySound("militaryalphabet/zulu");
		mySound.play();
	}
	else
	{
		MultiLineEdit1->insert( cutsoundMSG[soundCounter] );
		MultiLineEdit1->insert( "\n");
	}
	
	soundCounter++;
}
/*
 *  convert string to morse code
 */
void MilAlp::playMorseString()
{
	const QString cutmorseMSG = LineEdit2->text();

	if( cutmorseMSG[morseCounter] == "a" || cutmorseMSG[morseCounter] == "A" )
	{
		MultiLineEdit1->insert( "A:\t*-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "b" || cutmorseMSG[morseCounter] == "B" )
	{
		MultiLineEdit1->insert( "B:\t-***\n" );
	}
	else if( cutmorseMSG[morseCounter] == "c" || cutmorseMSG[morseCounter] == "C" )
	{
		MultiLineEdit1->insert( "C:\t-*-*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "d" || cutmorseMSG[morseCounter] == "D" )
	{
		MultiLineEdit1->insert( "D:\t-**\n" );
	}
	else if( cutmorseMSG[morseCounter] == "e" || cutmorseMSG[morseCounter] == "E" )
	{
		MultiLineEdit1->insert( "E:\t*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "f" || cutmorseMSG[morseCounter] == "F" )
	{
		MultiLineEdit1->insert( "F:\t**-*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "g" || cutmorseMSG[morseCounter] == "G" )
	{
		MultiLineEdit1->insert( "G:\t--*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "h" || cutmorseMSG[morseCounter] == "H" )
	{
		MultiLineEdit1->insert( "H:\t****\n" );
	}
	else if( cutmorseMSG[morseCounter] == "i" || cutmorseMSG[morseCounter] == "I" )
	{
		MultiLineEdit1->insert( "I:\t**\n" );
	}
	else if( cutmorseMSG[morseCounter] == "j" || cutmorseMSG[morseCounter] == "J" )
	{
		MultiLineEdit1->insert( "J:\t*---\n" );
	}
	else if( cutmorseMSG[morseCounter] == "k" || cutmorseMSG[morseCounter] == "K" )
	{
		MultiLineEdit1->insert( "K:\t-*-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "l" || cutmorseMSG[morseCounter] == "L" )
	{
		MultiLineEdit1->insert( "L:\t*-**\n" );
	}
	else if( cutmorseMSG[morseCounter] == "m" || cutmorseMSG[morseCounter] == "M" )
	{
		MultiLineEdit1->insert( "M:\t--\n" );
	}
	else if( cutmorseMSG[morseCounter] == "n" || cutmorseMSG[morseCounter] == "N" )
	{	
		MultiLineEdit1->insert( "N:\t-*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "o" || cutmorseMSG[morseCounter] == "O" )
	{	
		MultiLineEdit1->insert( "O:\t---\n" );
	}
	else if( cutmorseMSG[morseCounter] == "p" || cutmorseMSG[morseCounter] == "P" )
	{	
		MultiLineEdit1->insert( "P:\t*--*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "q" || cutmorseMSG[morseCounter] == "Q" )
	{	
		MultiLineEdit1->insert( "Q:\t--*-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "r" || cutmorseMSG[morseCounter] == "R" )
	{	
		MultiLineEdit1->insert( "R:\t*-*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "s" || cutmorseMSG[morseCounter] == "S" )
	{	
		MultiLineEdit1->insert( "S:\t***\n" );
	}
	else if( cutmorseMSG[morseCounter] == "t" || cutmorseMSG[morseCounter] == "T" )
	{	
		MultiLineEdit1->insert( "T:\t-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "u" || cutmorseMSG[morseCounter] == "U" )
	{	
		MultiLineEdit1->insert( "U:\t**-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "v" || cutmorseMSG[morseCounter] == "V" )
	{	
		MultiLineEdit1->insert( "V:\t***-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "w" || cutmorseMSG[morseCounter] == "W" )
	{	
		MultiLineEdit1->insert( "W:\t*--\n" );
	}
	else if( cutmorseMSG[morseCounter] == "x" || cutmorseMSG[morseCounter] == "X" )
	{	
		MultiLineEdit1->insert( "X:\t-**-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "y" || cutmorseMSG[morseCounter] == "Y" )
	{	
		MultiLineEdit1->insert( "Y:\t-*--\n" );
	}
	else if( cutmorseMSG[morseCounter] == "z" || cutmorseMSG[morseCounter] == "Z" )
	{	
		MultiLineEdit1->insert( "Z:\t--**\n" );
	}
	else if( cutmorseMSG[morseCounter] == "ä" || cutmorseMSG[morseCounter] == "Ä" )
	{	
		MultiLineEdit1->insert( "Ä:\t*-*-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "ö" || cutmorseMSG[morseCounter] == "Ö" )
	{	
		MultiLineEdit1->insert( "Ö:\t---*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "ü" || cutmorseMSG[morseCounter] == "Ü" )
	{	
		MultiLineEdit1->insert( "Ü:\t**--\n" );
	}
	else if( cutmorseMSG[morseCounter] == "ß" )
	{	
		MultiLineEdit1->insert( "ß:\t***--**\n" );
	}
	else if( cutmorseMSG[morseCounter] == "." )
	{	
		MultiLineEdit1->insert( ".:\t*-*-*-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "," )
	{
		MultiLineEdit1->insert( ",:\t--**--\n" );
	}
	else if( cutmorseMSG[morseCounter] == "@" )
	{
		MultiLineEdit1->insert( ",:\t*--*-*\n" );
	}
	else if( cutmorseMSG[morseCounter] == "?" )
	{
		MultiLineEdit1->insert( "?:\t**--**\n" );
	}
	else if( cutmorseMSG[morseCounter] == "0" )
	{
		MultiLineEdit1->insert( "0:\t-----\n" );
	}
	else if( cutmorseMSG[morseCounter] == "1" )
	{
		MultiLineEdit1->insert( "1:\t*----\n" );
	}
	else if( cutmorseMSG[morseCounter] == "2" )
	{
		MultiLineEdit1->insert( "2:\t**---\n" );
	}
	else if( cutmorseMSG[morseCounter] == "3" )
	{
		MultiLineEdit1->insert( "3:\t***--\n" );
	}
	else if( cutmorseMSG[morseCounter] == "4" )
	{
		MultiLineEdit1->insert( "4:\t****-\n" );
	}
	else if( cutmorseMSG[morseCounter] == "5" )
	{
		MultiLineEdit1->insert( "5:\t*****\n" );
	}
	else if( cutmorseMSG[morseCounter] == "6" )
	{
		MultiLineEdit1->insert( "6:\t-****\n" );
	}
	else if( cutmorseMSG[morseCounter] == "7" )
	{
		MultiLineEdit1->insert( "7:\t--***\n" );
	}
	else if( cutmorseMSG[morseCounter] == "8" )
	{
		MultiLineEdit1->insert( "8:\t---**\n" );
	}
	else if( cutmorseMSG[morseCounter] == "9" )
	{
		MultiLineEdit1->insert( "9:\t----*\n" );
	}
	else
	{
		MultiLineEdit1->insert( cutmorseMSG[morseCounter] );
		MultiLineEdit1->insert( "\n");
	}
	
	morseCounter++;
}

/*
 *  keyinput
*/
void MilAlp::convertKeys( const QString &string )
{
    
	//if( string.length() < MultiLineEdit1->length())
	//{
		MultiLineEdit1->setText("");
	//}
	unsigned int i;
	
	for(i=0; i<string.length(); i++)
	{
		if( string[i] == "a" || string[i] == "A" )
		{
			MultiLineEdit1->insert( "Alpha\n" );
		}
		else if( string[i] == "b" || string[i] == "B" )
		{
			MultiLineEdit1->insert( "Bravo\n" );
		}
		else if( string[i] == "c" || string[i] == "C" )
		{
			MultiLineEdit1->insert( "Charlie\n" );
		}
		else if( string[i] == "d" || string[i] == "D" )
		{
			MultiLineEdit1->insert( "Delta\n" );
		}
		else if( string[i] == "e" || string[i] == "E" )
		{
			MultiLineEdit1->insert( "Echo\n" );
		}
		else if( string[i] == "f" || string[i] == "F" )
		{
			MultiLineEdit1->insert( "Foxtrot\n" );
		}
		else if( string[i] == "g" || string[i] == "G" )
		{
			MultiLineEdit1->insert( "Golf\n" );
		}
		else if( string[i] == "h" || string[i] == "H" )
		{
			MultiLineEdit1->insert( "Hotel\n" );
		}
		else if( string[i] == "i" || string[i] == "I" )
		{
			MultiLineEdit1->insert( "India\n" );
		}
		else if( string[i] == "j" || string[i] == "J" )
		{
			MultiLineEdit1->insert( "Juliet\n" );
		}
		else if( string[i] == "k" || string[i] == "K" )
		{
			MultiLineEdit1->insert( "Kilo\n" );
		}
		else if( string[i] == "l" || string[i] == "L" )
		{
			MultiLineEdit1->insert( "Lima\n" );
		}
		else if( string[i] == "m" || string[i] == "M" )
		{
			MultiLineEdit1->insert( "Mike\n" );
		}
		else if( string[i] == "n" || string[i] == "N" )
		{
			MultiLineEdit1->insert( "November\n" );
		}
		else if( string[i] == "o" || string[i] == "O" )
		{
			MultiLineEdit1->insert( "Oscar\n" );
		}
		else if( string[i] == "p" || string[i] == "P" )
		{
			MultiLineEdit1->insert( "Papa\n" );
		}
		else if( string[i] == "q" || string[i] == "Q" )
		{
			MultiLineEdit1->insert( "Quebec\n" );
		}
		else if( string[i] == "r" || string[i] == "R" )
		{
			MultiLineEdit1->insert( "Romeo\n" );
		}
		else if( string[i] == "s" || string[i] == "S" )
		{
			MultiLineEdit1->insert( "Sierra\n" );
		}
		else if( string[i] == "t" || string[i] == "T" )
		{
			MultiLineEdit1->insert( "Tango\n" );
		}
		else if( string[i] == "u" || string[i] == "U" )
		{
			MultiLineEdit1->insert( "Uniform\n" );
		}
		else if( string[i] == "v" || string[i] == "V" )
		{
			MultiLineEdit1->insert( "Victor\n" );
		}
		else if( string[i] == "w" || string[i] == "W" )
		{
			MultiLineEdit1->insert( "Whiskey\n" );
		}
		else if( string[i] == "x" || string[i] == "X" )
		{
			MultiLineEdit1->insert( "X-Ray\n" );
		}
		else if( string[i] == "y" || string[i] == "Y" )
		{
			MultiLineEdit1->insert( "Yankee\n" );
		}
		else if( string[i] == "z" || string[i] == "Z" )
		{
			MultiLineEdit1->insert( "Zulu\n" );
		}
		else
		{
			MultiLineEdit1->insert( string[i] );
			MultiLineEdit1->insert( "\n");
		}
	}
}
